/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim:set ts=2 sw=2 sts=2 et cindent: */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: ML 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Mozilla code.
 *
 * The Initial Developer of the Original Code is the Mozilla Corporation.
 * Portions created by the Initial Developer are Copyright (C) 2007
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *  Chris Double <chris.double@double.co.nz>
 *  Mike Kristoffersen <mikek@mikek.dk>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

////////////////////////////////////////////////////////////////////////////////
//
//  See nsGStreamerDoc.txt for overall design documentation
//
//  See http://gstreamer.freedesktop.org/documentation/ for generic GStreamer
//  documentation
//
////////////////////////////////////////////////////////////////////////////////

#ifndef nsGStreamerDecoder_h__
#define nsGStreamerDecoder_h__

#include "nsISupports.h"
#include "nsMediaDecoder.h"

class nsGStreamerDecoder : public nsMediaDecoder
{
  // ISupports
  NS_DECL_ISUPPORTS

  // nsIObserver
  NS_DECL_NSIOBSERVER

  // Private constructor to prevent the object from being instantiated
  // as if it being virtual wasn't enough :)
  nsGStreamerDecoder(){};
public:
  virtual ~nsGStreamerDecoder(){};

  // Function to create a new instance of the GStreamer decoder
  //
  // NOTE: If we did it by letting the user instantiate an element of
  // this class we would have to drag a lot of GStreamer specific
  // header files in together with this header file.
  static nsGStreamerDecoder *makeNewInstance();

  // Create a new decoder of the same type as this one.
  virtual nsMediaDecoder* Clone() {return makeNewInstance();};

  // Forwarder function to enable access to a protected member of the base class
  void SetRGBData(PRInt32 aWidth,
                  PRInt32 aHeight,
                  float aFramerate,
                  float aAspectRatio,
                  unsigned char* aRGBBuffer)
                  {
                    nsMediaDecoder::SetRGBData(
                                                                aWidth,
                                                                aHeight,
                                                                aFramerate,
                                                                aAspectRatio,
                                                                aRGBBuffer);
                  };

  // Dummy function to forward invalidate calls
  // the return type doesn't mean anything, but the
  // template function used for the call needs it
  virtual PRBool ForwardInvalidate() = 0;
};

#endif
